###One stage IPD meta-analysis###
###Notes###
# In V3, code has been introduced to extract the BLUE (conditional mode) and corresponding CI's for each study. Whilst not standard practice, this has been done
# In line with comments at peer review. Code for a sensitivity analysis a has also been included which assesses the influence of removing a single observation at a time
#on the conclusions of the meta-analysis. This has only been done for the main models synthesizing all outcomes. 

setwd("D:/Load-velocity meta-analysis/Data analysis")
library(lmerTest)
library(ggplot2)
library(ggdist)
library(ggridges)
library(dplyr)

####################### DATA PREPARATION/Cleaning#############

#Load Data
meta.data.os<- read.csv("Meta_Data_Update.csv", header = T)

#Check data and summarise dataframe

str(meta.data.os)
summary(meta.data.os)

#Convert study, model, number of loads and MVT method to categorical variables

meta.data.os$Study<- as.factor(meta.data.os$Study)
meta.data.os$Model<- as.factor(meta.data.os$Model)
meta.data.os$Author<- as.factor(meta.data.os$Author)

#Reflect residuals such as that positive value represents overprediction 
#and a negative value represents under-prediction.

meta.data.os$Residual<- meta.data.os$Residual*-1

##Calculate actual 1RM for all studies
##To calculate actual 1RM the following formula is applied 
# Mean of actual and predicted - 0.5* [Reflected residual]

meta.data.os$Actual_1RM<- meta.data.os$Mean.Pred.Act - (0.5*meta.data.os$Residual)


##Create new vector comprising residuals scaled by the measured 1RM

meta.data.os$Residuals_Scaled<- (meta.data.os$Residual/ meta.data.os$Actual_1RM)*100


#Create exercise specific dataframes to be used in moderator analyses later.

meta.data.os.bench<- subset(meta.data.os, Exercise== "Bench Press")
meta.data.os.squat<- subset(meta.data.os, Exercise== "Squat")
meta.data.os.deadlift<- subset(meta.data.os, Exercise== "Deadlift")


#ridge plot demonstrating the distribution of residuals (raw data) by exercise 

ggplot(meta.data.os, aes(x=Exercise, y= Residuals_Scaled, fill= Exercise))+
  stat_halfeye(alpha=0.6, justification= -0.1, point_colour= NA, width= 0.6)+
  geom_boxplot(outlier.shape = NA, alpha=0.6, width= 0.2)+ 
  theme_classic()+ 
  coord_flip()+ 
  theme(legend.position = "none", axis.text = element_text(colour = "black"))


#Convert predictor variables/fixed effects from character to factor

meta.data.os$Model<- factor(meta.data.os$Model)
meta.data.os$Exercise<- factor(meta.data.os$Exercise)
meta.data.os$Num_loads_cat<- factor(meta.data.os$Num_loads_cat)
meta.data.os$MVTGroup.MVTInd<- factor(meta.data.os$MVTGroup.MVTInd)

#Relevel variables for interpretation. 

meta.data.os$Exercise<- relevel(meta.data.os$Exercise, "Bench Press")
meta.data.os$Num_loads_cat<-relevel(meta.data.os$Num_loads_cat, "Two")
meta.data.os$MVTGroup.MVTInd<-relevel(meta.data.os$MVTGroup.MVTInd, "Group")


###One stage IPD meta-analysis###
#Create null (intercept) only models for both scaled and unscaled residuals
#The (1|Study/Model) notation below indicates that models are nested within studies
#(i.e.,there may be more than one model per study). 
#Under this model specification, each study receives it's own unique intercept, and each model within a study also obtains a unique intercept,
#allowing for both between and within study variation to be modeled 

int.only.raw<-lmer(Residual~ 1+ (1|Study/Model), data = meta.data.os)
int.only.scaled<- lmer(Residuals_Scaled ~ 1 + (1|Study/Model), data = meta.data.os)

#Visual inspection of model appropriateness
#The call below plots "pearson" residuals against the model fitted values

plot(int.only.raw)
plot(int.only.scaled)


#obtain summaries of both models 

summary(int.only.raw)
summary(int.only.scaled)

#Obtain cluster-robust standard errors, 95% confidence intervals and p-values for model parameters.
#The "::" denotes that the package has not 'actively been loaded' using the "library()" command. 

clubSandwich::conf_int(int.only.raw, vcov = "CR2")
clubSandwich::conf_int(int.only.scaled, vcov = "CR2")
clubSandwich::coef_test(int.only.raw, vcov = "CR2")
clubSandwich::coef_test(int.only.scaled, vcov="CR2")


##Sensitivity analysis##
#First, create a new variable which contains each unique instance of a model, this is done as the following steps require
#us to specify that one specific model should be excluded each time. 

models_sensitivity<- unique(meta.data.os$Model)

#Create an empty list where the results will later get stored 

sensitivity_list<- list()

#Run a for loop which first creates a subset of the original dataframe, removing the ith model (1-107) This is then used to create a new "null" (or intercept only) model
#This happens for each model sequentially, with the loop removing one model at a time.
#Each lmer model (which corresponding to one iteration) is then stored as an element in the empty list we created earlier

for (i in 1:length(models_sensitivity)){
  
  subset.data<- subset(meta.data.os, Model != models_sensitivity[i]) # Create a subset of the original dataframe by removing one model
  
  null.model<- int.only.raw<-lmer(Residual~ 1+ (1|Study/Model), data = subset.data)# Use the subsetted data for a create a new lmer model
  
  sensitivity_list[[i]]<- null.model # save the resulting lmer model as a single element in the list

  
}



# Extract the fixed effect/intercept/beta coefficient from each model
fixed_effects <- unlist(lapply(sensitivity_list, function(model) coef(model)$fixed))

# View the extracted fixed effects
print(fixed_effects)

meta.data.os.mod<- meta.data.os[!meta.data.os$Covidence.identifier== 838, ]

#Mixed effects model built with Exercise included as a fixed effect.
Mod.Exercise<- lmer(Residual ~ Exercise + (1|Study/Model), data = meta.data.os.mod)
Mod.Exercise.Scaled<- lmer(Residuals_Scaled ~ Exercise + (1|Study/Model), data = meta.data.os.mod)

#Obtain Cluster-robust 95% confidence for models

clubSandwich::conf_int(Mod.Exercise, vcov = "CR2")
clubSandwich::coef_test(Mod.Exercise, vcov = "CR2")
clubSandwich::conf_int(Mod.Exercise.Scaled, vcov = "CR2")
clubSandwich::coef_test(Mod.Exercise.Scaled, vcov = "CR2")

## Get rid of any observations where the number of loads is not reported.
meta.data.os.loads<- meta.data.os.mod[!meta.data.os.mod$Num_loads_cat== "NR", ]

#Ensure variable is of the class factor

meta.data.os.loads$Num_loads_cat<- as.factor(meta.data.os.loads$Num_loads_cat)

#Relevel such that the reference level is the "two point" method.

meta.data.os.loads$Num_loads_cat<- relevel(meta.data.os.loads$Num_loads_cat, ref = "Two")

#Create model with number of loads as fixed effect 
Mod.num.loads.raw<- lmer(Residual ~ Num_loads_cat + (1|Study/Model), data = meta.data.os.loads)
Mod.num.loads.scaled<- lmer(Residuals_Scaled ~ Num_loads_cat + (1|Study/Model), data = meta.data.os.loads)

clubSandwich::conf_int(Mod.num.loads.raw, vcov = "CR2")
clubSandwich::coef_test(Mod.num.loads.raw, vcov = "CR2")
clubSandwich::conf_int(Mod.num.loads.scaled, vcov = "CR2")
clubSandwich::coef_test(Mod.num.loads.scaled, vcov = "CR2")

#Similar to the code above, this removes any observations where the extrapolation method used was not reported. 

meta.data.os.mvt<- meta.data.os.mod[!meta.data.os.mod$MVTGroup.MVTInd== "NR", ]

#Create model with group versus individualised MVT as predictor
mod.MVT.raw<- lmer(Residual ~ MVTGroup.MVTInd + (1|Study/Model), data = meta.data.os.mvt)
mod.MVT.scaled<- lmer(Residuals_Scaled ~ MVTGroup.MVTInd + (1|Study/Model), data = meta.data.os.mvt)

clubSandwich::conf_int(mod.MVT.raw, vcov = "CR2")
clubSandwich::coef_test(mod.MVT.raw, vcov = "CR2")
clubSandwich::conf_int(mod.MVT.scaled, vcov = "CR2")
clubSandwich::coef_test(mod.MVT.scaled, vcov = "CR2")


###Code for generating plots for one stage analysis###

#This code generates a plot with all of the data and assigns colours to the points
#Based on the exercise.

One.Stage.Plot<- ggplot(meta.data.os, aes(x= Residual, y= Author))+
  geom_point(alpha= 0.4, aes(colour= Exercise))

#Extract model CI's from one stage analysis and store in a new variable called 
#CI.Model.All

CI.Model.All<- clubSandwich::conf_int(int.only.raw, vcov = "CR2")


#Create a dataframe consisting of CI data and "author" name to add a pooled estimate (i.e., estimated intercept from analyses) to plot 
#This is done as ggplot only works with dataframes.
#The indexing in the UB and LB signifies the value from the first row and columns 5/6, respectively should be extracted and used.
#This needs to be done as the saved variable is in the format of a dataframe, and thus needs two dimensions to be specified. 

model.global<-data.frame(Author= "Pooled", Est= fixef(int.only.raw), UB= CI.Model.All[1,6], LB= CI.Model.All[1,5])


One.Stage.Plot<- One.Stage.Plot+ geom_point(data = model.global, aes(x= Est, y= Author), size= 3, shape= 18)+
  geom_segment(x= model.global$LB, xend= model.global$UB, y= model.global$Author, yend= model.global$Author)+
  scale_y_discrete(limits= c("Pooled", "Alonso", "Balsalobre", "Bernavidez", "Berton", "Bishop", "Callaghan", "Caven",
                             "Cetin", "Garcia-Ramos", "Hughes", "Janicijevic", "Jukic", "Kilgallon", "Macarilla", "Nickerson",
                             "Perez-Castilla", "Perez-Castilla(a)", "Ruf", "Thompson", "Williams"), labels= c("Pooled", "Jimenez-Alonso[6]", "Balsalobre-Fernandez[4]", "Bernavidez[5]", "Berton[7]", "Bishop[5]", "Callaghan[5]", "Caven[8]",
                                                                                                              "Cetin [7]", "Garcia-Ramos[7]", "Hughes[4]", "Janicijevic[4]", "Jukic[5]", "Kilgallon[4]", "Macarilla[1]", "Nickerson[5]",
                                                                                                              "Perez-Castilla[6]", "Perez-Castilla(a)[3]", "Ruf[3]", "Thompson[6]", "Williams[4]"))+
  theme_classic()+ xlim(-40,40)+ 
  theme(axis.text = element_text(colour = "Black"),
        axis.title.y = element_blank())+
  xlab("Residuals (Predicted-Measured)")
  

##Add study specific intercepts with corresponding confidence intervals
#This requires us to extract the BLUP (best linear unbiased prediction) and associated standard deviation for each study
#This code first produces a dataframe with all of the information required
#The point estimate for each study denoted as "condval", the CI is then constructed by multiplying the condsd by 1.96 in either direction,
#and adding this to the BLUE (conditional mode).

Stud.specific.est<- as.data.frame(ranef(int.only.raw))
Stud.specific.est<- Stud.specific.est[108:127, ]
CI_Upper<- Stud.specific.est$condval + (1.96*Stud.specific.est$condsd) 
CI_Lower<- Stud.specific.est$condval - (1.96*Stud.specific.est$condsd) 
  
  
Stud.specific.est["CI_Upper"]<- CI_Upper
Stud.specific.est["CI_Lower"]<- CI_Lower
  
meta.data.os.dedup<- meta.data.os[!duplicated(meta.data.os$Study), ] 
Stud.specific.est["Author"]<- meta.data.os.dedup$Author

  


One.Stage.Plot<- One.Stage.Plot + geom_point(data = Stud.specific.est, aes(x= condval, y= Author), size= 3, shape= 18)


One.Stage.Plot.cont<- One.Stage.Plot + geom_segment(data = Stud.specific.est, aes(x= Stud.specific.est$CI_Lower, xend= Stud.specific.est$CI_Upper, y= Stud.specific.est$Author,
                                                                                  yend= Stud.specific.est$Author))






