### Version 4###

##In V4 of the code, all instances of 1:107 have been replaced with unique function
#This allows number of mdoels in data set to change, without manual changing of code to reflect.

## In V3 of the code, sensitivity analyses have been included for all main models##
##in V2 code has been edited to include 66 models instead of 69.
#Hughes trial 2 data imported, hughes (ID:75 removed)
#Bench pull study and models using cross-multiplication also removed.
#Code to remove LD0 models from the squat nmodel has been removed for now

setwd("D:/Load-velocity meta-analysis/Data analysis")
library(metafor)
library(ggplot2)

####################### DATA PREPARATION, CLEANING AND DEFINING FUNCTIONS################

#Load Data

meta.data<- read.csv("Meta_Data_Update.csv", header = T)
meta.data$Model<- factor(meta.data$Model)

#Set seed for reproducible results. This works such that everytime the same reference number is
#inside of the argument set.seed, the exact same results should be returned.

set.seed(23061230)

#Define function for calculating SEE from model residuals. This function needs an input "x"
#which in this case is the vector (or column) containing the residual data

SEE<- function(x){
  sqrt(sum(x^2)/(length(x)-2))
}

#Test SEE function. Here the SEE command simply tells the R environment to run the user defined SEE function
#The rep function takes two arguments. The first is the object to be repeated. In this case, the number 10.
#The second is the number of repeats or iterations to be completed, in this case 100 and 1000, respectively.
#When put together, the code tells R to run the SEE function on two vectors, one with 100 instances of 10,
#and the other with 1000 instances of 10.

SEE(rep(10,100))
SEE(rep(10,1000))

#Define function for bootstrapping. This will be used later within a tapply function to generate
#1000 SEE values for each model contained in the data set. 

#The function takes two arguments, one which specifies the data set. The other
#specifies the number of iterations/bootstrapped samples, with a default value of 1000. 


Bootstrap<- function(data, iterations = 1000){
  int<- lapply(1:iterations, function(i) sample(data, replace = T))
  Calc.SEE<- sapply(int, SEE)
}


#Calculate SEE for each model.
#This is calculated manually as not all studies report this metric. 
#In this instance, the tapply function is telling R to take the column containing the residuals
#and calculate the SEE for each model in the analysis. 
#It is important that the INDEX argument is supplied a factor variable. 
SEE.Est<- tapply(meta.data$Residual, INDEX = meta.data$Model, SEE)

#Because tapply outputs the results in list format (1 element per level of the factor/ index variable),
#The following code is applied to transform this back into vector format.
#the result is a vector/column of length 69, where each observation corresponds to the SEE for one model in the dataset.
SEE.Est<-as.vector(SEE.Est)

#Adding SEE point estimates to original dataframe.
summary_counts <- data.frame(Model = unique(meta.data$Model), SEE.Est)
meta.data<-merge(meta.data, summary_counts, by = "Model")

#Calculate SEE% (SEE/criterion mean) expressed as a percentage.
#Calculated manually as not all studies include this metric.
SEE_Percentage<-(meta.data$SEE.Est/meta.data$Criterion.Mean)*100

#Append SEE% to dataframe
meta.data<-cbind(meta.data, SEE_Percentage)


#Generating 1000 bootstrapped SEE's for each model. This is used to help estimate the sampling variance/standard error
#of the SEE statistic for each model in the dataset, as there are no commonly used/recommended formula to achieve this.
#These values will be required later when building the meta-analystic models.
#This outputs a list containing 69 elements, where each element is length 1000
#Each element represents a single model, with a vector comprised of 1000 SEE values.
#The bootstrap function defined earlier in the page is used here. 

#set another seed for reproducible results as bootstrapping is a stochastic process.
set.seed(20072248)

#Similar to the tapply function above which calculates 1 SEE value per model, the following code tells R
#To apply the bootstrap function we defined above separately to each
#level of the variable "Model". This results in 1000 SEE values being produced for each model in the dataset.

Bootstrapped_SEE<- tapply(meta.data$Residual, INDEX = meta.data$Model, FUN = Bootstrap)


#Prepare data to convert scale SEE values by criterion mean. 
#This will output a new list with 1000 SEE% values, instead of 1000 SEE values
#The variance of each element (and therefore SEE% distribution per model) will then be calculated
#And this will be taken to be the sampling variance.

#Delete duplicate observations such that there is only 1 observation per model.
meta.data<- meta.data[!duplicated(meta.data$Model), ]

#Order dataframe by model
meta.data<- meta.data[order(meta.data$Model), ]

#Initialise/create list to store results from for loop.
Bootstrapped_SEE_Per <- list()

#For loop to scale SEE values
#The [[i]] denontes a sub-element of each list element while [i] denontes an element of the vector 
#"Criterion.Mean"

#The [[i]] notation works by treating each level of the list as a vector
#This means that when performing operations, each sub-element of the list is treated as an 
#"element", instead of the dataframe itself.

for( i in 1:length(Bootstrapped_SEE)){
  Bootstrapped_SEE_Per[[i]] <- (Bootstrapped_SEE[[i]]/ meta.data$Criterion.Mean[i])*100
}

#Visual inspection of bootstrapping results. 

#Create new df called "graph data" for visualisation purposes
Graph_Data<- data.frame(SEE=unlist(Bootstrapped_SEE), SEE_Percents=unlist(Bootstrapped_SEE_Per))
Graph_Data$Model<- rep(paste("Model", unique(meta.data$Model), sep = " "), each=1000)
Graph_Data$Iteration<- rep(1:1000, times= length(unique(meta.data$Model)))

#Boxplots of bootstrapped SEE and SEE% data
Box_SEE<- ggplot(Graph_Data, aes(y=SEE))+ geom_boxplot()+ facet_wrap(~Model)
Box_SEE_Percent<- ggplot(Graph_Data, aes(y=SEE_Percents))+ geom_boxplot()+ facet_wrap(~Model)

#Lineplots of SEE and SEE% data to assess convergence (i.e., whether number of interations should be increased)
BootViz_SEE<- ggplot(Graph_Data, aes(y= SEE, x= Iteration))+ geom_line()+ facet_wrap(~Model)
Bootviz_SEE_Percent<- ggplot(Graph_Data, aes(y= SEE_Percents, x= Iteration))+ geom_line()+ facet_wrap(~Model)+
  ylab("SEE%")

#Calculate sampling variance and standard error of SEE and SEE% for each model using bootstrapped SEE% and SEE values.

SEE_Per_Variance<- lapply(Bootstrapped_SEE_Per, var)
See_Per_standard_error<- lapply(Bootstrapped_SEE_Per, sd)
SEE_Var<- lapply(Bootstrapped_SEE, var)
SEE_standard_error<-lapply(Bootstrapped_SEE, sd)

#Combine SEE% sampling variances with main dataframe
#Left hand defines new variable name, right hand ensures values are not in list format.

meta.data$SEE_Percentage_Variance= unlist(SEE_Per_Variance)
meta.data$SEE_Var= unlist(SEE_Var)

#subset data to remove residuals. This is mainly for ease of viewing and for output of final CSV.
meta.data<- meta.data[, -5]

#Take dataframe and output a csv file to be included in supplementary material.

write.csv(meta.data, "Meta-analysis full data.csv")


#Check distribution of bootstrapped estimates for each model
#This will help identify if model assumptions are appropriate 
#Or of transformations need to be completed. 

#First, Create a naming vector to name each plot

Plot_Name_Vec<- paste0("Model ", 1:length(Bootstrapped_SEE_Per))

#Create for loop which dynamically creates density plots for each variable

for (i in seq_along(Bootstrapped_SEE_Per)){
  
  plot(density(Bootstrapped_SEE_Per[[i]]), main = Plot_Name_Vec[i])
  
}


#Create qqplot of the same

for (i in seq_along(Bootstrapped_SEE_Per)){
  
  qqnorm(Bootstrapped_SEE_Per[[i]], main = Plot_Name_Vec[i])
  qqline(Bootstrapped_SEE_Per[[i]], col= "steelblue", lwd=2)
  
}




#################### START OF META-ANALYSIS #####################################


#Build and run a 3 level hierarchical model using metafor package.
#The model is specified to account for the fact that there are multiple models per study
#and that effects are therefore not independent. This is denoted by "Study/Model", which indicates a nested structure.


#Drop any studies/models that do not have sampling variances for SEE%

meta.data.amend<- meta.data[!is.na(meta.data$SEE_Percentage_Variance), ]

#Ensure moderator variables are of the class factor

meta.data.amend$Num_loads_cat<- factor(meta.data.amend$Num_loads_cat)
meta.data.amend$MVTGroup.MVTInd<- factor(meta.data.amend$MVTGroup.MVTInd)
meta.data.amend$Modality<- factor(meta.data.amend$Modality)



#Build pooled model for all outcomes.

Model_all<- rma.mv(yi= SEE_Percentage,    #"Effect"
                   V= SEE_Percentage_Variance,  #Sampling variances
                   slab = Author,  #This tells the model how to label outcomes.
                   data = meta.data.amend, #Data to use
                   test = "z", method = "REML", #Restricted maximum likelihood estimation
                   random = ~ 1 | Study/Model) #Defines random effects per study and per model within a study.





#Output model results.

Model_all


#Generate robust model estimates where the 'cluster' command indicates
#which variable to use to indicate how outcomes are "nested" or "clustered"

Robust_Model_all<- robust(Model_all, cluster = meta.data.amend$Study)

#Output robust model estimates.

Robust_Model_all



#visual plots to examine model appropriateness#

#residual plot

plot(resid(Model_all, type= "pearson"), main = "Standardised residuals from model_all")
abline(h=0, lwd= 2, col = "red")

#histogram and qqplot of residuals for further inspection

hist(resid(Model_all, type = "pearson"), col= "lightblue", main = "Histogram of standardised residuals from model_all")
abline(v= 0, lty= 2, col= "red", lwd = 3)

qqnorm(resid(Model_all, type = "pearson"))
qqline(resid(Model_all, type = "pearson"), col= "red", lwd= 2)


#Define function for calculating ICC from three level models
#This is done by dividing the variance of level 3 (between-study) by the sum of the variances at all other levels
#Here "x" corresponds to the specific model and "y" refers to the level 1 variance, calculated as the median of the sampling variances estimated from bootstrapping
#the [1] index tells R to extract the variance from level 3 only.

ICC<- function(x,y){
  
x$sigma2[1]/sum((x$sigma2 + median(y)))

}


##Calculate ICC for "Model_all"
#Note that level 1 is taken as the median of the sampling variances estimated from bootstrapping for see% data.

ICC(x= Model_all, y= meta.data.amend$SEE_Percentage_Variance)


##Obtain confidence intervals for random effects/variance parameters (within and between study variation)

confint(Robust_Model_all)


#Create a vector containing the model labels for all models

model.labs<-as.character(meta.data$Model)


#Caterpillar plot
#This plot is similar to a standard forest plot, except point estimates are graphed in order 
#of magnitude. This creates a curved appearance to the point estimates.
#The function "order" is what allows r to graph the observations in this way 

forest(Robust_Model_all$yi, Robust_Model_all$vi,
       xlab = "SEE%",
       order = Robust_Model_all$yi,
       slab = meta.data.amend$Model, annotate = F,
       efac = 0,
       pch = 19,
       col= "gray40",
       xlim = c(-5, 40),
       alim = c(0, 40),
       at= c(0,10,20,30,40),
       cex.lab = 0.75,
       cex.axis = 0.75,
       lty = c("solid", "blank"))


#Draw points one more time to make easier to make them easier to see
points(sort(Robust_Model_all$yi),
       Robust_Model_all$k.all:1, pch=19, cex=0.5)

#Add a summary "poly" into caterpillar plot whcih represents the pooled estimate of the SEE%
#across all outcomes synthesised.

addpoly(Robust_Model_all,
        mlab = "",
        annotate = FALSE,
        cex = 2,
        efac = 1.0,
        row = 0.2)


####Sensitivity analysis for main model using the leave one out approach#####
###Note that this was not included in manuscript, however for transparency has been included here###

set.seed(19062023)

# Get unique models
models_sens <- unique(meta.data.amend$Model)

# Initialize sensitivity results list. This creates an empty list which will be used to store results
sensitivity_results <- list()


# Perform sensitivity analysis
for (i in 1:length(models_sens)) {
  
  # Create new dataset without the current model
  data_subset <- meta.data.amend[meta.data.amend$Model != models_sens[i], ]
  
  # Fit metafor model on the new dataset. 
  #Note that data_subset is used to indicate the new subset data with the "ith" observation removed should be used
  
  Result <- rma.mv(yi = SEE_Percentage,
                   V = SEE_Percentage_Variance,
                   slab = Author,
                   data = data_subset,
                   test = "z",
                   method = "REML",
                   random = ~ 1 | Study/Model)
  
  
  # Store model output in the sensitivity results list
  sensitivity_results[[i]] <- Result
}


##Visualise distribution of model estimates effects###

# Extract fixed effects (intercepts) from sensitivity results
fixed_effects <- sapply(sensitivity_results, function(x) x$beta[1])

# Plot the distribution of fixed effects
hist(fixed_effects, main = "Distribution of Model estimates from LOO analysis", xlab = "Fixed Effects (Intercept)", col = "#CF9FFF", border = "white")



###Boostrapping of main model to estimate any bias in model parameters###

# Set the number of bootstrap iterations
n_bootstrap <- 1000

# Create a list to store the bootstrapped models
boot_models <- vector("list", n_bootstrap)

# Perform bootstrapping and fit models
for (i in 1:n_bootstrap) {
  # Generate a bootstrap sample
  bootstrap_sample <- meta.data.amend[sample(nrow(meta.data.amend), replace = TRUE), ]
  
  # Fit the model using rma.mv
  model <- rma.mv(yi = SEE_Percentage,
                  V = SEE_Percentage_Variance,
                  slab = Author,
                  data = bootstrap_sample,
                  test = "z", method = "REML",
                  random = ~ 1 | Study/Model)
  
  # Store the model in the list
  boot_models[[i]] <- model
}


# Extract beta coefficients using lapply
beta_coefficients <- unlist(lapply(boot_models, function(model) coef(model)[[1]]))




#####Moderator/sub-group analyses#####

meta.data.mod<- meta.data.amend

#Ensure that variables to be used in moderator analyses are the appropriate class "factor"

meta.data.mod$Exercise<- factor(meta.data.mod$Exercise)
meta.data.mod$Num_loads_cat<- factor(meta.data.mod$Num_loads_cat)
meta.data.mod$MVTGroup.MVTInd<- factor(meta.data.mod$MVTGroup.MVTInd)


#Re-order the levels of "Exercise" such that Bench Press can be specified as a reference category.

meta.data.mod$Exercise<- relevel(meta.data.mod$Exercise, ref = "Bench Press")

#Re-order the levels of "Num_loads_cat" such that Two is specified as the reference category.

meta.data.mod$Num_loads_cat<- relevel(meta.data.mod$Num_loads_cat, "Two")

#Re-order the levels of "MVTGroup.MVTInd" such that Group is specified as the reference category.

meta.data.mod$MVTGroup.MVTInd<- relevel(meta.data.mod$MVTGroup.MVTInd, "Group")

#Keep only observations where the method of extrapolation is "MVT".  
#This is done due to the low number of studies employing other methods
#With LD0 used in only one study for one exercise 

meta.data.mod<-meta.data.mod[meta.data.mod$LDO.MVT.Cross== "MVT", ]
meta.data.mod<- subset(meta.data.mod, meta.data.mod$MVTGroup.MVTInd != "NR")
meta.data.mod<- meta.data.mod[!meta.data.mod$Covidence.identifier== 838, ]

#Generate table to visualize factor combinations

table(meta.data.mod$Exercise, meta.data.mod$Num_loads_cat)
table(meta.data.mod$Exercise, meta.data.mod$MVTGroup.MVTInd)
table(meta.data.mod$Exercise, meta.data.mod$LDO.MVT.Cross)

#Moderator analyses for Exercise assessed.

Model_mod_exercise<- rma.mv(yi= SEE_Percentage, 
                       V= SEE_Percentage_Variance, 
                       slab = Author, 
                       data = meta.data.mod,
                       mods = ~ Exercise,
                       test = "z", method = "REML",
                       random = ~ 1 | Study/Model)


#Robust estimates 

Robust_Model_Exercise<- robust(Model_mod_exercise, meta.data.mod$Study)

#Obtain ICC for model

ICC(Robust_Model_Exercise, meta.data.mod$SEE_Percentage_Variance)

#Obtain confidence interval for model

confint(Robust_Model_Exercise)


#Model for number of loads
#Delete observations where number of loads are "NA" or "NR"

meta.data.mod<- subset(meta.data.mod, Num_loads_cat!= "NR")
meta.data.mod<-meta.data.mod[!is.na(meta.data.mod$Num_loads_cat), ]

#Specify model

 Model_Num_Loads<- rma.mv(yi= SEE_Percentage, 
                             V= SEE_Percentage_Variance, 
                             slab = Author,
                             mods = ~ Num_loads_cat,
                             data = meta.data.mod,
                             test = "z", method = "REML",
                             random = ~ 1 | Study/Model)




#Obtain robust estimate of model standard errors and interval estimates for model coefficients
Robust_model_num_loads<- robust(Model_Num_Loads, cluster = meta.data.mod$Study)

#Moderator analyses for use of individualised MVT versus Pooled MVT

meta.data.mod<- meta.data.mod[!meta.data.mod$MVTGroup.MVTInd== "NR", ]
meta.data.mod<- meta.data.mod[!meta.data.mod$MVTGroup.MVTInd== "Vlast", ]



Model_MVT<- rma.mv(yi= SEE_Percentage, 
                   V= SEE_Percentage_Variance, 
                   slab = Author, 
                   data = meta.data.mod,
                   mods = ~ MVTGroup.MVTInd,
                   test = "z", method = "REML",
                   random = ~ 1 | Study/Model)

robust_model_MVT<- robust(Model_MVT, meta.data.mod$Study)



###Building exercise specific models to generate pooled SEE estimates in "raw" format"
#Subset main data to include only the Bench Press Exercise

meta.data.bench<- subset(meta.data.amend, Exercise== "Bench Press")
meta.data.bench$Modality<- factor(meta.data.bench$Modality)

#Build multilevel meta-analysis model using the the unscaled (i.e., raw) SEE values.

Model_Bench_Raw<- rma.mv(yi= SEE.Est, 
                   V= SEE_Var, 
                   slab = Author, 
                   data = meta.data.bench,
                   test = "z", method = "REML",
                   random = ~ 1 | Study/Model)

#Obtain confidence intervals for random effects

confint(Model_Bench_Raw)

#Obtain model ICC

ICC(x= Model_Bench_Raw, y= median(meta.data.bench$SEE_Percentage_Variance))

#Generate robust standard errors and CI's

Robust_Model_Bench<- robust(Model_Bench_Raw, meta.data.bench$Study)

Robust_Model_Bench


#Build multi-level meta-analysis model to pool scaled SEE's (SEE%)

Model_Bench_Scaled<- rma.mv(yi= SEE_Percentage, 
                             V= SEE_Percentage_Variance, 
                             slab = Author, 
                             data = meta.data.bench,
                             test = "z", method = "REML",
                             random = ~ 1 | Study/Model)

confint(Model_Bench_Scaled)


robust(Model_Bench_Scaled, meta.data.bench$Study)

##Moderator analyses for bench press
#Bench_Mode model will investigate the influence of the modality (i.e., free-weight vs smith-machine)


Bench_Mode<- rma.mv(yi= SEE.Est, 
                    V= SEE_Var, 
                    slab = Author, 
                    data = meta.data.bench,
                    mods = ~ Modality,
                    test = "z", method = "REML",
                    random = ~ 1 | Study/Model)


#obtain cluster robust SE's and CI's

robust(Bench_Mode, meta.data.bench$Study)


#Moderator analysis to assess influence of number of loads#

#Subset data, removing instances where the number of loads were not reported

meta.data.bench<- subset(meta.data.bench, Num_loads_cat!= "NR")

#Ensure that the "two point" approach is the reference level

meta.data.bench$Num_loads_cat<- relevel(factor(meta.data.bench$Num_loads_cat), "Two")

#Build multilevel model for moderator analyses investigating influence of number of loads

Bench_Model_num_loads<- Model_Bench<- rma.mv(yi= SEE.Est, 
                                             V= SEE_Var, 
                                             slab = Author, 
                                             data = meta.data.bench,
                                             mods = ~ Num_loads_cat,
                                             test = "z", method = "REML",
                                             random = ~ 1 | Study/Model)

#Obtain cluster robust estimates

robust(Bench_Model_num_loads, meta.data.bench$Study)

#Obtain confidence intervals for random effects 

confint(Bench_Mode)

# Build multilevel model for moderatory analysis investigating effect of MVT approach selected

Bench_MVT<- rma.mv(yi= SEE.Est, 
                   V= SEE_Var, 
                   slab = Author, 
                   data = meta.data.bench,
                   mods = ~ Num_loads_cat,
                   test = "z", method = "REML",
                   random = ~ 1 | Study/Model)


#Obtain cluster-robust estimates 

robust(Bench_MVT, meta.data.bench$Study)


#Take the mean relative strength value away from all observations (i.e., center on mean)
#remove rows with missing relative strength values 
meta.data.bench$Centered_Rel_Strength<- (meta.data.bench$Relative_Strength- mean(meta.data.bench$Relative_Strength))

#Run exploratory meta-regression of to assess influence of relative strength.

Bench_Rel_Strength<- rma.mv(yi= SEE.Est, 
                            V= SEE_Var, 
                            slab = Author, 
                            data = meta.data.bench,
                            mods = ~ meta.data.bench$Centered_Rel_Strength,
                            test = "z", method = "REML",
                            random = ~ 1 | Study/Model)

robust(Bench_Rel_Strength, meta.data.bench$Study)


#Plot meta-regression.

Bench_Rel_Strength_plot<- regplot(Bench_Rel_Strength,
                                  pch = 19,
                                  xlab = "Mean centered relative strength",
                                  ylab = "Standard error of estimate",
                                  col = alpha("#B51DF3", 0.3))



###Deadlift###

meta.data.deadlift<- subset(meta.data.amend, Exercise== "Deadlift")

Model_Deadlift<- rma.mv(yi= SEE.Est, 
                     V= SEE_Var, 
                     slab = Author, 
                     data = meta.data.deadlift,
                     test = "z", method = "REML",
                     random = ~ 1 | Study/Model)

#Obtain variance parameters and CI's

confint(Model_Deadlift)

#Obtain ICC

ICC(x= Model_Deadlift, y= meta.data.deadlift$SEE_Var)

#Obtain cluster-robust estimates

Robust_Model_Deadlift<- robust(Model_Deadlift, meta.data.deadlift$Study)

Robust_Model_Deadlift

#Obtain confidence intervals for variance parameters,

confint(Model_Deadlift)

#Produce a model incorporating scaled SEE (SEE%)

Model_Deadlift_Scaled<-rma.mv(yi= SEE_Percentage, 
                              V= SEE_Percentage_Variance, 
                              slab = Author, 
                              data = meta.data.deadlift,
                              test = "z", method = "REML",
                              random = ~ 1 | Study/Model)

#Obtain variance parameters and associated CI's.

confint(Model_Deadlift_Scaled)


#Obtain ICC for scaled model

ICC(x= Model_Deadlift_Scaled, y= meta.data.deadlift$SEE_Percentage_Variance)

#Obtain cluster robust SE and CI's for scaled model.

robust(Model_Deadlift_Scaled, meta.data.deadlift$Study)



#Squat

meta.data.squat<- subset(meta.data, meta.data$Exercise== "Squat")


Model_Squat<- rma.mv(yi= SEE.Est, 
                        V= SEE_Var, 
                        slab = Author, 
                        data = meta.data.squat,
                        test = "z", method = "REML",
                        random = ~ 1 | Study/Model)


robust(Model_Squat, meta.data.squat$Study)

confint(Model_Squat)



Model_Squat_Scaled<- rma.mv(yi= SEE_Percentage, 
                     V= SEE_Percentage_Variance, 
                     slab = Author, 
                     data = meta.data.squat,
                     test = "z", method = "REML",
                     random = ~ 1 | Study/Model)

robust(Model_Squat_Scaled, meta.data.squat$Study)


